package com.bsz.school_send_back_end.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.bsz.school_send_back_end.common.ErrorCode;
import com.bsz.school_send_back_end.exception.BusinessException;
import com.bsz.school_send_back_end.exception.ThrowUtils;
import com.bsz.school_send_back_end.model.domain.Business;
import com.bsz.school_send_back_end.model.domain.Orders;
import com.bsz.school_send_back_end.model.domain.User;
import com.bsz.school_send_back_end.model.domain.UserRating;
import com.bsz.school_send_back_end.service.BusinessService;
import com.bsz.school_send_back_end.service.OrdersService;
import com.bsz.school_send_back_end.service.UserRatingService;
import com.bsz.school_send_back_end.mapper.UserRatingMapper;
import com.bsz.school_send_back_end.service.UserService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;

/**
* @author pc
* @description 针对表【user_rating(用户评分)】的数据库操作Service实现
* @createDate 2024-12-09 16:06:45
*/
@Service
public class UserRatingServiceImpl extends ServiceImpl<UserRatingMapper, UserRating>
    implements UserRatingService{

    @Resource
    private UserService userService;

    @Resource
    private OrdersService ordersService;

    @Resource
    private BusinessService businessService;

    @Override
    public void validUserRating(UserRating userRating, HttpServletRequest request) {

        if (userRating.getRating() < 1 || userRating.getRating() > 5) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "分数不在可选范围内");
        }

        User loginUser = userService.getLoginUser(request);
        if (!loginUser.getId().equals(userRating.getUserId())) {
            throw new BusinessException(ErrorCode.NOT_FOUND_ERROR, "当前登录用户与评分中的用户不匹配");
        }
        Orders orders = ordersService.getOne(Wrappers.<Orders>lambdaQuery().eq(Orders::getId, userRating.getOrderId()));
        ThrowUtils.throwIf(orders == null, ErrorCode.NOT_FOUND_ERROR, "订单不存在");
        ThrowUtils.throwIf(!orders.getBusinessId().equals(userRating.getBusinessId()) ,ErrorCode.NOT_FOUND_ERROR, "该商家与订单商家不一致");

        long count = this.count(Wrappers.<UserRating>lambdaQuery().eq(UserRating::getOrderId, userRating.getOrderId()));
        ThrowUtils.throwIf(count > 0, ErrorCode.SYSTEM_ERROR, "该订单已评分");
    }

    @Override
    public void validUserRatingByBusiness(Long userRatingId, HttpServletRequest request) {
        LambdaQueryWrapper<UserRating> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(UserRating::getId, userRatingId);
        UserRating userRating = this.getOne(queryWrapper);
        Business loginBusiness = businessService.getLoginBusiness(request);
        Long businessId = loginBusiness.getId();
        if (!businessId.equals(userRating.getBusinessId())) {
            throw new BusinessException(ErrorCode.OPERATION_ERROR,"该用户评分不属于当前商家");
        }
        if (StringUtils.isBlank(userRating.getReview())) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR, "当前用户没有评论");
        }
        if (StringUtils.isNotBlank(userRating.getBusinessReview())) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR,"当前用户评分已回复");
        }
    }

}




