package com.bsz.school_send_back_end.utils;

import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.text.SimpleDateFormat;
import java.util.*;

/**
 * 多商家取餐码生成工具
 * 每个商家每天的取餐码从1开始独立计数
 */
@Component
public class UniqueNumberGenerator {
    // 商家取餐码的序列号记录，key为"商家ID_日期"，value为序列号
    private static final Map<String, Integer> merchantSequenceMap = new HashMap<>();
    private static final Random random = new Random(); // 随机数生成器
    private static final SimpleDateFormat dateFormat = new SimpleDateFormat("yyyyMMdd");

    /**
     * 根据商家ID生成17位的唯一取餐编号
     * 格式：日期(8位) + 随机数(5位) + 序列号(4位)
     *
     * @param businessId 商家ID
     * @return 唯一编号
     */
    public static synchronized String generateNumber(Long businessId) {
        // 获取当前日期
        String currentDate = dateFormat.format(new Date());

        // 生成商家当天的唯一key
        String key = businessId + "_" + currentDate;

        // 获取商家当前日期的序列号，没有则初始化为1
        int sequenceNumber = merchantSequenceMap.getOrDefault(key, 1);

        // 更新商家的序列号
        merchantSequenceMap.put(key, sequenceNumber + 1);

        // 生成中间5位的随机数
        int middleRandom = 10000 + random.nextInt(90000); // 生成10000到99999之间的随机数

        // 格式化序列号为4位
        String sequenceStr = String.format("%04d", sequenceNumber);

        // 组合并返回结果
        return currentDate + middleRandom + sequenceStr;
    }

    @Scheduled(cron = "0 0 0 * * ?")
    public static void cleanOldData() {
        String currentDate = dateFormat.format(new Date());
        Iterator<String> iterator = merchantSequenceMap.keySet().iterator();

        while (iterator.hasNext()) {
            String key = iterator.next();
            String date = key.split("_")[1]; // 获取key中的日期部分
            if (!date.equals(currentDate)) {
                iterator.remove(); // 移除过期的key
            }
        }
    }
}
